searchData={"items":[{"type":"module","title":"Membrane.Element.GCloud.SpeechToText","doc":"An element providing speech recognition via Google Cloud Speech To Text service\nusing Streaming API.\n\nThe element has to handle a connection time limit (currently 5 minutes). It does that\nby spawning multiple streaming clients - the streaming is stopped after `streaming_time_limit` (see `t:t/0`) and a new client that starts streaming is spawned. The old one is kept alive for `results_await_time` and will receive recognition results for the streamed audio.\n\nThis means that first results from the new client might arrive before the last result\nfrom an old client.\n\nBear in mind that `streaming_time_limit` + `results_await_time` must\nbe smaller than recognition time limit for Google Streaming API\n(currently 5 minutes)","ref":"Membrane.Element.GCloud.SpeechToText.html"},{"type":"module","title":"Element options - Membrane.Element.GCloud.SpeechToText","doc":"Passed via struct `t:Membrane.Element.GCloud.SpeechToText.t/0`\n\n- `language_code`  \n\n  ```\n  String.t()\n  ```\n  \n  Default value: `\"en-US\"`  \n  The language of the supplied audio.\n  See [Language Support](https://cloud.google.com/speech-to-text/docs/languages)\n  for a list of supported languages codes.\n\n\n- `interim_results`  \n\n  ```\n  boolean()\n  ```\n  \n  Default value: `false`  \n  If set to true, the interim results may be returned by recognition API.\n  See [Google API docs](https://cloud.google.com/speech-to-text/docs/reference/rpc/google.cloud.speech.v1#google.cloud.speech.v1.StreamingRecognitionConfig)\n  for more info.\n\n\n\n- `word_time_offsets`  \n\n  ```\n  boolean()\n  ```\n  \n  Default value: `false`  \n  If `true`, the top result includes a list of words and the start and end time offsets (timestamps) for those words.\n\n\n\n- `speech_contexts`  \n\n  ```\n  [%SpeechContext{}]\n  ```\n  \n  Default value: `[]`  \n  A list of speech recognition contexts. See [the docs](https://cloud.google.com/speech-to-text/docs/reference/rpc/google.cloud.speech.v1#google.cloud.speech.v1.RecognitionConfig)\n  for more info.\n\n\n\n- `model`  \n\n  ```\n  :default | :video | :phone_call | :command_and_search\n  ```\n  \n  Default value: `:default`  \n  Model used for speech recognition. Bear in mind that `:video` model\n  is a premium model that costs more than the standard rate.\n\n\n\n- `streaming_time_limit`  \n\n  ```\n  Time.t()\n  ```\n  \n  Default value: `200000000000`  \n  Determines how much audio can be sent to recognition API in one\n  client session. After this time, a new client session is created\n  while the old one is kept alive for some time to receive recognition\n  results.\n  \n  Bear in mind that `streaming_time_limit` + `results_await_time` must\n  be smaller than recognition time limit for Google Streaming API\n  (currently 5 minutes)\n\n\n\n- `results_await_time`  \n\n  ```\n  Time.t()\n  ```\n  \n  Default value: `90000000000`  \n  The amount of time a client that stopped streaming is kept alive\n  awaiting results from recognition API.\n\n\n\n- `reconnection_overlap_time`  \n\n  ```\n  Time.t()\n  ```\n  \n  Default value: `2000000000`  \n  Duration of audio re-sent in a new client session after reconnection","ref":"Membrane.Element.GCloud.SpeechToText.html#module-element-options"},{"type":"module","title":"Pads - Membrane.Element.GCloud.SpeechToText","doc":"### `:input`\n\nAccepted formats:\n```\nFLAC\n```\n\nDirection: | `:input`\nAvailability: | `:always`\nFlow control: | `:manual`\nDemand unit: | `:buffers`","ref":"Membrane.Element.GCloud.SpeechToText.html#module-pads"},{"type":"function","title":"Membrane.Element.GCloud.SpeechToText.options/0","doc":"Returns description of options available for this module","ref":"Membrane.Element.GCloud.SpeechToText.html#options/0"},{"type":"type","title":"Membrane.Element.GCloud.SpeechToText.t/0","doc":"Struct containing options for `Membrane.Element.GCloud.SpeechToText`","ref":"Membrane.Element.GCloud.SpeechToText.html#t:t/0"},{"type":"extras","title":"Membrane Multimedia Framework: GCloud Speech To Text","doc":"# Membrane Multimedia Framework: GCloud Speech To Text\n\n[![Hex.pm](https://img.shields.io/hexpm/v/membrane_element_gcloud_speech_to_text.svg)](https://hex.pm/packages/membrane_element_gcloud_speech_to_text)\n[![CircleCI](https://circleci.com/gh/membraneframework/membrane_element_gcloud_speech_to_text.svg?style=svg)](https://circleci.com/gh/membraneframework/membrane_element_gcloud_speech_to_text)\n\nThis package provides a Sink wrapping [Google Cloud Speech To Text Streaming API client](https://hex.pm/packages/gcloud_speech_grpc).\nCurrently supports only audio streams in FLAC format.\n\nThe docs can be found at [HexDocs](https://hexdocs.pm/membrane_element_gcloud_speech_to_text).","ref":"readme.html"},{"type":"extras","title":"Installation - Membrane Multimedia Framework: GCloud Speech To Text","doc":"The package can be installed by adding `membrane_element_gcloud_speech_to_text` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:membrane_element_gcloud_speech_to_text, \"~> 0.10.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - Membrane Multimedia Framework: GCloud Speech To Text","doc":"To use the element you need a `config/config.exs` file with Google credentials:\n\n```elixir\nuse Mix.Config\n\nconfig :goth, json: \"a_path/to/google/credentials/creds.json\" |> File.read!()\n```\n\nMore info on how to configure credentials can be found in [README of Goth library](https://github.com/peburrows/goth#installation)\nused for authentication.","ref":"readme.html#configuration"},{"type":"extras","title":"Usage - Membrane Multimedia Framework: GCloud Speech To Text","doc":"The input stream for this element should be parsed, so most of the time it should be\nplaced in pipeline right after [FLACParser](https://github.com/membraneframework/membrane-element-flac-parser)\n\nHere's an example of pipeline streaming audio file to speech recognition API:\n\n```elixir\ndefmodule SpeechRecognition do\n  use Membrane.Pipeline\n\n  alias Google.Cloud.Speech.V1.StreamingRecognizeResponse\n\n  @impl true\n  def handle_init(_ctx, _options) do\n    spec =\n      child(%Membrane.File.Source{location: \"sample.flac\"})\n      |> child(Membrane.FLAC.Parser)\n      |> child(%Membrane.Element.GCloud.SpeechToText{\n          interim_results: false,\n          language_code: \"en-GB\",\n          word_time_offsets: true\n        })\n\n    {[spec: links], %{}}\n  end\n\n  @impl true\n  def handle_child_notification(%StreamingRecognizeResponse{} = response, _element, _ctx, state) do\n    IO.inspect(response)\n    {[], state}\n  end\n\n  @impl true\n  def handle_child_notification(_notification, _element, _ctx, state) do\n    {[], state}\n  end\nend\n```\n\nThe pipeline also requires [a config file](#configuration) and the following dependencies:\n\n```elixir\n[\n  {:membrane_core, \"~> 1.0\"},\n  {:membrane_file_plugin, \"~> 0.16.0\"},\n  {:membrane_flac_plugin, \"~> 0.11.0\"},\n\t{:membrane_element_gcloud_speech_to_text, \"~> 0.10.0\"}\n]\n```","ref":"readme.html#usage"},{"type":"extras","title":"Testing - Membrane Multimedia Framework: GCloud Speech To Text","doc":"Tests tagged `:external` are excluded by default since they contact the real API and require\nconfiguration of credentials. See [Configuration](#configuration)","ref":"readme.html#testing"},{"type":"extras","title":"Fixture - Membrane Multimedia Framework: GCloud Speech To Text","doc":"A recording fragment in `test/fixtures` comes from an audiobook\n\"The adventures of Sherlock Holmes (version 2)\" available on [LibriVox](https://librivox.org/the-adventures-of-sherlock-holmes-by-sir-arthur-conan-doyle/)","ref":"readme.html#fixture"},{"type":"extras","title":"Copyright and License - Membrane Multimedia Framework: GCloud Speech To Text","doc":"Copyright 2019, [Software Mansion](https://swmansion.com/?utm_source=git&utm_medium=readme&utm_campaign=membrane-element-gcloud-speech-to-text)\n\n[![Software Mansion](https://logo.swmansion.com/logo?color=white&variant=desktop&width=200&tag=membrane-github)](https://swmansion.com/?utm_source=git&utm_medium=readme&utm_campaign=membrane-element-gcloud-speech-to-text)\n\nLicensed under the [Apache License, Version 2.0](LICENSE)","ref":"readme.html#copyright-and-license"},{"type":"extras","title":"LICENSE","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n\n   APPENDIX: How to apply the Apache License to your work.\n\n      To apply the Apache License to your work, attach the following\n      boilerplate notice, with the fields enclosed by brackets \"[]\"\n      replaced with your own identifying information. (Don't include\n      the brackets!)  The text should be enclosed in the appropriate\n      comment syntax for the file format. We also recommend that a\n      file or class name and description of purpose be included on the\n      same \"printed page\" as the copyright notice for easier\n      identification within third-party archives.\n\n   Copyright 2019 Software Mansion\n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.","ref":"license.html"}],"content_type":"text/markdown"}